@@ -4,7 +4,7 @@
 --[[
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2011  Otfried Cheong
+    Copyright (C) 1993-2013  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -49,6 +49,25 @@ function MODEL:paction(a)
   if a:sub(1,5) == "mode_" then
     self.mode = a:sub(6)
     if prefs.tablet_mode then
+      local snapmodes = {"snapvtx", "snapbd", "snapint", "snapgrid",
+			 "snapangle", "snapauto"}
+      -- disable snapping in ink mode
+      if self.mode == "ink" then
+	self.savedsnap = {}
+	for i,e in ipairs(snapmodes) do
+	  self.savedsnap[e] = self.snap[e]
+	  self.snap[e] = false
+	end
+      elseif self.savedsnap then
+	-- reenable snapping when switching back to another mode
+	for i,e in ipairs(snapmodes) do self.snap[e] = self.savedsnap[e] end
+	self.savedsnap = nil
+      end
+      for i,e in ipairs(snapmodes) do
+	self.ui:setActionState(e, self.snap[e])
+      end
+      self.ui:setSnap(self.snap)
+      self.ui:setFifiVisible(self.mode ~= "ink")
       self.ui:setSelectionVisible(self.mode ~= "ink")
       self.ui:setCursor()
     end
@@ -279,36 +298,22 @@ end
 function MODEL:showLayerBoxPopup(v, layer)
   local p = self:page()
   local m = ipeui.Menu(self.ui:win())
-  local canDelete = true
-  local canLock = true
-  -- layers active in some view cannot be deleted or locked
-  for j = 1, p:countViews() do
-    if layer == p:active(j) then
-      canDelete = false
-      canLock = false
-      break
-    end
-  end
-  -- layers containing an object cannot be deleted
-  for i,obj,sel,l in p:objects() do
-    if l == layer then
-      canDelete = false
-      break
-    end
-  end
-  m:add("rename", "Rename")
-  if canDelete then
-    m:add("delete", "Delete")
+  local active = p:active(self.vno)
+  m:add("checkfrom", "Check " .. layer .. " from view " .. self.vno)
+  m:add("rename", "Rename " .. layer)
+  m:add("delete", "Delete " .. layer)
+  if layer ~= active then
+    m:add("merge", "Merge into " .. active)
   end
   if p:isLocked(layer) then
-    m:add("lockoff", "Unlock")
-  elseif canLock then
-    m:add("lockon", "Lock")
+    m:add("lockoff", "Unlock " .. layer)
+  else
+    m:add("lockon", "Lock " .. layer)
   end
   if p:hasSnapping(layer) then
-    m:add("snapoff", "Disable snapping")
+    m:add("snapoff", "Disable snapping for " .. layer)
   else
-    m:add("snapon", "Enable snapping")
+    m:add("snapon", "Enable snapping for " .. layer)
   end
   local layers = p:layers()
   if #layers > 1 then
@@ -332,6 +337,23 @@ end
 
 ----------------------------------------------------------------------
 
+function MODEL:layeraction_checkfrom(layer, arg)
+  local p = self:page()
+  local t = { label="make layer " .. layer .. " visible from view " .. self.vno,
+	      pno=self.pno,
+	      vno=self.vno,
+	      original=p:clone(),
+	      layer=layer,
+	      undo=revertOriginal
+	    }
+  t.redo = function (t, doc)
+	     for j = t.vno, doc[t.pno]:countViews() do
+	       doc[t.pno]:setVisible(j, t.layer, true)
+	     end
+	   end
+  self:register(t)
+end
+
 function MODEL:layeraction_select(layer, arg)
   local p = self:page()
   local t = { label="set visibility of layer " .. layer,
@@ -353,6 +375,14 @@ end
 
 function MODEL:layeraction_lock(layer, arg)
   local p = self:page()
+  for j = 1, p:countViews() do
+    if layer == p:active(j) then
+      self:warning("Cannot lock layer '" .. layer .. "'.",
+		   "Layer '" .. layer .. "' is the active layer of view "
+		     .. j .. ".")
+      return
+    end
+  end
   local t = { label="set locking of layer " .. layer,
 	      pno=self.pno,
 	      vno=self.vno,
@@ -392,7 +422,11 @@ end
 function MODEL:layeraction_move(layer, arg)
   local p = self:page()
   local target = 1
-  if arg ~= "_top_" then target = indexOf(arg, p:layers()) end
+  local current = indexOf(layer, p:layers())
+  if arg ~= "_top_" then
+    target = indexOf(arg, p:layers())
+    if target < current then target = target + 1 end
+  end
   local t = { label="move layer " .. layer,
 	      pno=self.pno,
 	      vno=self.vno,
@@ -431,11 +465,11 @@ end
 
 function MODEL:layeraction_rename(layer)
   local p = self:page()
-  local name = self:getString("Enter new layer name")
+  local name = self:getString("Enter new name for layer '" .. layer .. "'")
   if not name then return end
   name = string.gsub(name, "%s+", "_")
   if indexOf(name, p:layers()) then
-    self:warning("Cannot rename layer",
+    self:warning("Cannot rename layer '" .. layer .. "'.",
 		 "The name '" .. name .. "' is already in use.")
     return
   end
@@ -462,10 +496,11 @@ end
 
 function MODEL:layeraction_delete(layer)
   local p = self:page()
-  for i,obj,sel,lay in p:objects() do
-    if lay == layer then
-      self:warning("Cannot delete layer",
-		   "Layer '" .. layer .. "' is not empty.")
+  for j = 1, p:countViews() do
+    if layer == p:active(j) then
+      self:warning("Cannot delete layer '" .. layer .. "'.",
+		   "Layer '" .. layer .. "' is the active layer of view "
+		     .. j .. ".")
       return
     end
   end
@@ -477,7 +512,44 @@ function MODEL:layeraction_delete(layer)
 	      undo=revertOriginal
 	    }
   t.redo = function (t, doc)
-	     doc[t.pno]:removeLayer(t.layer)
+	     local p = doc[t.pno]
+	     for i = #p,1,-1 do
+	       if p:layerOf(i) == t.layer then
+		 p:remove(i)
+	       end
+	     end
+	     p:removeLayer(t.layer)
+	   end
+  self:register(t)
+end
+
+function MODEL:layeraction_merge(layer)
+  local p = self:page()
+  local active = p:active(self.vno)
+  for j = 1, p:countViews() do
+    if layer == p:active(j) then
+      self:warning("Cannot remove layer '" .. layer .. "'.",
+		   "Layer '" .. layer .. "' is the active layer of view "
+		     .. j .. ".")
+      return
+    end
+  end
+  local t = { label="merge layer " .. layer .. " into " .. active,
+	      pno=self.pno,
+	      vno=self.vno,
+	      original=p:clone(),
+	      layer=layer,
+	      target=active,
+	      undo=revertOriginal
+	    }
+  t.redo = function (t, doc)
+	     local p = doc[t.pno]
+	     for i = 1,#p do
+	       if p:layerOf(i) == t.layer then
+		 p:setLayerOf(i, t.target)
+	       end
+	     end
+	     p:removeLayer(t.layer)
 	   end
   self:register(t)
 end
@@ -520,6 +592,11 @@ function MODEL:action_quit()
   ipeui.closeAllWindows()
 end
 
+function MODEL:action_auto_latex()
+  self.auto_latex = self.ui:actionState("auto_latex")
+  print("Auto is", self.auto_latex)
+end
+
 ----------------------------------------------------------------------
 
 function MODEL:action_new()
@@ -1001,6 +1078,10 @@ end
 
 function MODEL:action_delete_view()
   local p = self:page()
+  if p:countViews() < 2 then
+    self.ui:explain("cannot delete single view of a page")
+    return
+  end
   local t = { label="delete view",
 	      pno = self.pno,
 	      vno0 = self.vno,
@@ -1308,6 +1389,10 @@ end
 function MODEL:action_page_sorter()
   local arr = self.ui:pageSorter(self.doc)
   if not arr then return end -- canceled
+  if #arr == 0 then
+    self:warning("You cannot delete all pages of the document")
+    return
+  end
   -- compute reverse 'permutation'
   local rev = {}
   for i = 1,#self.doc do rev[i] = 0 end
@@ -1734,6 +1819,7 @@ end
 function MODEL:action_update_style_sheets()
   local dir = nil
   if self.file_name then dir = string.gsub(self.file_name, "[^/]+$", "") end
+  if dir == "" then dir = "." end
   local sheets = self.doc:sheets()
   local qlog = ""
   for index=1,sheets:count() do
@@ -2021,19 +2107,23 @@ end
 
 function MODEL:saction_add_clipping()
   local p = self:page()
-  local prim = p:primarySelection()
-  local obj = p[prim]
-  assert(obj:type() == "group")
   local sel = self:selection()
   if #sel ~= 2 then
-    self:warning("Must have exactly one secondary selection")
+    self:warning("Must have exactly one two selected objects")
     return
   end
-  local sec = (sel[1] ~= prim) and sel[1] or sel[2]
-  if p[sec]:type() ~= "path" then
-    self:warning("Secondary selection is not a path")
+  local prim = sel[1]
+  local sec = sel[2]
+  if p[prim]:type() ~= "group" then
+    prim = sel[2]
+    sec = sel[1]
+  end
+  local obj = p[prim]
+  if obj:type() ~= "group" or p[sec]:type() ~= "path" then
+    self:warning("Must select exactly one group and one path")
     return
   end
+
   local shape = p[sec]:shape()
   transformShape(p[sec]:matrix(), shape)
   transformShape(obj:matrix():inverse(), shape)
